@@ -22,11 +22,9 @@ THE SOFTWARE.
 -}
 module Data.Colour.Internal where
 
-import Data.List
+import Data.List (foldl1')
 import qualified Data.Colour.Chan as Chan
 import Data.Colour.Chan (Chan(Chan))
-import Data.Monoid
-import Data.Semigroup
 
 data Red = Red
 data Green = Green
@@ -55,12 +53,11 @@ black :: (Num a) => Colour a
 black = RGB Chan.empty Chan.empty Chan.empty
 
 instance (Num a) => Semigroup (Colour a) where
-  (<>) = mappend
+  (RGB r1 g1 b1) <> (RGB r2 g2 b2) =
+    RGB (r1 `Chan.add` r2) (g1 `Chan.add` g2) (b1 `Chan.add` b2)
 
 instance (Num a) => Monoid (Colour a) where
   mempty = black
-  (RGB r1 g1 b1) `mappend` (RGB r2 g2 b2) =
-    RGB (r1 `Chan.add` r2) (g1 `Chan.add` g2) (b1 `Chan.add` b2)
   mconcat l = RGB (Chan.sum lr) (Chan.sum lg) (Chan.sum lb)
    where
     (lr,lg,lb) = unzip3 (map toRGB l)
@@ -173,11 +170,10 @@ instance ColourOps AlphaColour where
 
 -- | 'AlphaColour' forms a monoid with 'over' and 'transparent'.
 instance (Num a) => Semigroup (AlphaColour a) where
-  (<>) = mappend
+  (<>) = over
 
 instance (Num a) => Monoid (AlphaColour a) where
   mempty = transparent
-  mappend = over
 
 -- | @c1 \`atop\` c2@ returns the 'AlphaColour' produced by covering
 -- the portion of @c2@ visible by @c1@.
