@@ -22,10 +22,9 @@ THE SOFTWARE.
 -}
 module Data.Colour.RGB where
 
-import Data.List
+import Data.List (elemIndex, transpose)
 import Data.Colour.Matrix
 import Data.Colour.CIE.Chromaticity
-import Control.Applicative
 
 -- |An RGB triple for an unspecified colour space.
 data RGB a = RGB {channelRed :: !a
